@@ -1,7 +1,7 @@
 context("Return type")
 
 test_that("return type for xlsx files", {
-  types <- read_excel(test_sheet("missing-values.xlsx"))
+  types <- read_excel(test_sheet("missing-values-xlsx.xlsx"))
   expect_is(types, "tbl_df")
   expect_is(types, "tbl")
   expect_is(types, "data.frame")
@@ -9,7 +9,7 @@ test_that("return type for xlsx files", {
 })
 
 test_that("return type for xls files", {
-  types <- read_excel(test_sheet("missing-values.xls"))
+  types <- read_excel(test_sheet("missing-values-xls.xls"))
   expect_is(types, "tbl_df")
   expect_is(types, "tbl")
   expect_is(types, "data.frame")
